@@ -1,24 +1,36 @@
-# To change this license header, choose License Headers in Project Properties.
-# To change this template file, choose Tools | Templates
-# and open the template in the editor.
-
+""" Extension for PDBIO to include additional output formats"""
 import sys
 
 from Bio.PDB.PDBIO import PDBIO
 from Bio.Data.IUPACData import atom_weights
 
-_ATOM_FORMAT_STRING = ("%s%5i %-4s%c%3s %c%4i%c   %8.3f%8.3f%8.3f%s%6.2f      %4s%2s\n")
+_ATOM_FORMAT_STRING =       ("%s%5i %-4s%c%3s %c%4i%c   %8.3f%8.3f%8.3f%s%6.2f      %4s%2s\n")
 _ATOM_FORMAT_STRING_PDBQT = ("%s%5i %-4s%c%3s %c%4i%c   %8.3f%8.3f%8.3f%s%6.2f    %6.3f %s\n")
+_ATOM_FORMAT_STRING_PQR =   ("%s%5i %-4s%c%3s %c%4i%c   %8.3f%8.3f%8.3f%s%6.2f      %4s%2s\n")
+_ATOM_FORMAT_STRING_CMIP =  ("%s%5i %-4s%c%3s %c%4i%c   %8.3f%8.3f%8.3f%8s  %-5s%s%s\n")
 
 
 class PDBIO_extended(PDBIO):
+    """ Extended classe to support additional output formats"""
+    def __init__(self, use_model_flag=0, is_pqr=False, output_format='pdb'):
+        super().__init__(use_model_flag, is_pqr)
+        self.output_format = output_format
 
-    def _get_atom_line(self, atom, hetfield, segid, atom_number, resname, resseq, icode, chain_id, charge="   "):
+    def _get_atom_line(
+            self,
+            atom, 
+            hetfield,
+            segid,
+            atom_number,
+            resname,
+            resseq,
+            icode,
+            chain_id,
+            charge="   "):
         """
             Return an ATOM PDB string (PRIVATE).
             Extended to allow for variable formatting
         """
-
         if hetfield != " ":
             record_type = "HETATM"
         else:
@@ -63,10 +75,24 @@ class PDBIO_extended(PDBIO):
                 )
         # Added charges (from res_library and atom_types from data_library)
         # Format PDBQT for Autodock
-        if hasattr(atom, "charge"):
-            charge = atom.charge
-            element = atom.ADT_type
-            format = _ATOM_FORMAT_STRING_PDBQT
+        
+        if atom.pqr_charge is not None and self.output_format != 'pdb':
+            if self.output_format == 'pdbqt':
+                charge = atom.pqr_charge
+                element = atom.xtra['atom_type']                
+                format = _ATOM_FORMAT_STRING_PDBQT
+            elif self.output_format == 'pqr':
+                occupancy_str = "%6.2f" % atom.pqr_charge
+                bfactor = atom.radius
+                format = _ATOM_FORMAT_STRING_PQR
+            elif self.output_format == 'cmip':
+                occupancy_str = "%8.4f" % atom.pqr_charge
+                bfactor = atom.xtra['atom_type']
+                element = "  "
+                format = _ATOM_FORMAT_STRING_CMIP
+            else:
+                print("Unknown output format, writing standard PDB")
+                format = _ATOM_FORMAT_STRING
         else:
             format = _ATOM_FORMAT_STRING
 
