@@ -6,7 +6,7 @@ from os.path import join as opj
 from os.path import dirname
 from biobb_structure_checking.param_input import Dialog
 
-VERSION = '3.9.4'
+VERSION = '3.9.7'
 
 # Default locations and settings
 DATA_DIR_DEFAULT_PATH = 'dat'
@@ -125,7 +125,14 @@ CMD_LINE.add_argument(
 CMD_LINE.add_argument(
     '-o', '--output',
     dest='output_structure_path',
-    help='Output structure. Format PDB|PDBQT|PQR|CMIP'
+    help='Output structure. Formats available pdb|pdbqt|pqr|cmip (use file extension or --output_format to set format)'
+)
+
+CMD_LINE.add_argument(
+    '--output_format',
+    dest='output_format',
+    help='Format for the Output. When empty output file extension is used.',
+    choices=['pdb', 'pdbqt', 'pqr', 'cmip']
 )
 
 CMD_LINE.add_argument(
@@ -219,7 +226,11 @@ DIALOGS.add_option('command_list', '--list', 'op_list', 'Command List File or st
 
 DIALOGS.add_entry('models', 'Checks and selects models')
 DIALOGS.add_option('models', '--select', 'select', \
-    'Select model to keep', int)
+    'Select model(s) to keep')
+DIALOGS.add_option('models', '--save_split', 'save_split', \
+    'Save each model in a separated PDB file', 'bool')
+DIALOGS.add_option('models', '--superimpose', 'superimpose', \
+    'Superimpose models', 'bool')
 
 DIALOGS.add_entry('chains', 'Checks and selects chains')
 DIALOGS.add_option('chains', '--select', 'select',\
@@ -347,6 +358,8 @@ MSGS = {
     'MODELS_GUESS': 'Models {} superimpose, RMSd: {:8.3f} A, guessed as {} ',
     'SINGLE_MODEL': 'Single model found',
     'SELECT_MODEL': 'Selecting model num.',
+    'SPLIT_MODELS': 'Splitting models for output',
+    'SUPIMP_MODELS': 'Models superimposed: final RMSd {:8.3f} A',
     #chains
     'CHAINS_DETECTED': '{} Chain(s) detected',
     'UNKNOWN_CHAINS':   ' {}: Unknown (PROTEIN: {s[0]:4.2f} DNA: {s[1]:4.2f} ' +\
